@@ -34,8 +34,8 @@
  */
 
 #define MAJOR_VERSION 2
-#define MINOR_VERSION 3
-#define BUILD_TYPE BetaCode
+#define MINOR_VERSION 4
+#define BUILD_TYPE ReleaseCode
 #define BUILD_NUMBER 1
 
 
